import enum


class Locale(enum.Enum):
    ENGLISH_AU = "en-AU"
    ENGLISH_CA = "en-CA"
    ENGLISH_GB = "en-GB"
    ENGLISH_IN = "en-IN"
    ENGLISH_US = "en-US"
    ENGLISH_ES = "en-ES"
    GERMAN = "de-DE"
    SPANISH_ES = "es-ES"
    SPANISH_MX = "es-MX"
    FRENCH_CA = "fr-CA"
    FRENCH_FR = "fr-FR"
    ITALIAN = "it-IT"
    JAPANESE = "ja-JP"
